import { ChevronRight, Menu, User } from "lucide-react";

import {
	Accordion,
	AccordionContent,
	AccordionItem,
	AccordionTrigger,
} from "@/components/ui/accordion";
import {
	Sheet,
	SheetContent,
	SheetDescription,
	SheetTitle,
	SheetTrigger,
} from "@/components/ui/sheet";
import { Link } from "@/i18n/routing";
import { headerData } from "@/utils/get-fake-data";

import { HeaderProps } from "./header-2";

export default function MobileNavigation2({ locale }: HeaderProps) {
	const { menuItems } = headerData.navigation;

	return (
		<Sheet>
			<SheetTrigger asChild>
				<button className="p-2 lg:hidden" aria-label="Open menu">
					<Menu className="size-6" />
				</button>
			</SheetTrigger>
			<SheetContent
				side="right"
				className="w-full max-w-[300px] overflow-y-auto bg-white p-0 text-[#606676] sm:w-[400px]"
			>
				<SheetTitle className="sr-only">Navigation Menu</SheetTitle>
				<SheetDescription className="sr-only">
					Access navigation options and user account
				</SheetDescription>
				<div className="flex h-full flex-col">
					<div className="bg-[#29ABE2] p-6">
						<Link
							href="/login"
							className="flex items-center gap-2 text-white transition-colors hover:text-white/80"
						>
							<User className="size-6" />
							<span className="text-lg font-semibold">
								{locale === "ar"
									? "تسجيل دخول / تسجيل حساب"
									: "Login / Register"}
							</span>
						</Link>
					</div>
					<nav className="flex-1 p-6">
						<ul className="space-y-6">
							{menuItems?.map((item) => (
								<li key={item.href}>
									{item.hasDropdown ? (
										<Accordion
											type="single"
											collapsible
											className="border-b border-gray-200"
										>
											<AccordionItem value={item.href} className="border-none">
												<AccordionTrigger className="py-2 text-lg transition-colors hover:text-[#29ABE2]">
													{item.label?.[locale]}
												</AccordionTrigger>
												<AccordionContent>
													<ul className="mt-2 space-y-2">
														{item.dropdownItems?.map((dropdownItem) => (
															<li key={item.href}>
																<Link
																	href={item.href as any}
																	className="block py-2 pr-4 transition-colors hover:text-[#29ABE2]"
																>
																	{dropdownItem.label?.[locale]}
																</Link>
															</li>
														))}
													</ul>
												</AccordionContent>
											</AccordionItem>
										</Accordion>
									) : (
										<Link
											href={"/"}
											className={`flex items-center justify-between py-2 transition-colors hover:text-[#29ABE2] ${item.active ? "font-bold" : ""
												}`}
										>
											{item.label?.[locale]}
											<ChevronRight className="size-5" />
										</Link>
									)}
								</li>
							))}
						</ul>
					</nav>
				</div>
			</SheetContent>
		</Sheet>
	);
}
